@@ -6,6 +6,7 @@ from annofabcli.experimental import (
     dashboard,
     find_break_error,
     list_labor_worktime,
+    mask_user_info,
     merge_peformance_per_user,
     write_peformance_per_user,
     write_scatter_per_user,
@@ -19,6 +20,7 @@ def parse_args(parser: argparse.ArgumentParser):
     dashboard.add_parser(subparsers)
     list_labor_worktime.add_parser(subparsers)
     find_break_error.add_parser(subparsers)
+    mask_user_info.add_parser(subparsers)
     merge_peformance_per_user.add_parser(subparsers)
     write_peformance_per_user.add_parser(subparsers)
     write_scatter_per_user.add_parser(subparsers)
