@@ -2,6 +2,7 @@
 import logging
 from dataclasses import dataclass
 from pathlib import Path
+from typing import Optional
 
 import holoviews as hv
 import numpy as np
@@ -33,9 +34,9 @@ class Histogram:
     ヒストグラムを出力するクラス
     """
 
-    def __init__(self, outdir: str, project_id: str):
+    def __init__(self, outdir: str, filename_prefix: Optional[str] = None):
         self.histogram_outdir = outdir
-        self.short_project_id = project_id[0:8]
+        self.filename_prefix = filename_prefix + "-" if filename_prefix is not None else ""
         Path(self.histogram_outdir).mkdir(exist_ok=True, parents=True)
 
     @staticmethod
@@ -99,9 +100,9 @@ class Histogram:
             logger.info("タスク一覧が0件のため出力しません。")
             return
 
-        output_file_worktime = f"{self.histogram_outdir}/{self.short_project_id}-ヒストグラム-1回目の教師付者ごと-教師付時間"
+        output_file_worktime = f"{self.histogram_outdir}/{self.filename_prefix}ヒストグラム-1回目の教師付者ごと-教師付時間"
         logger.debug(f"{output_file_worktime}.html を出力します。")
-        output_file_first_worktime = f"{self.histogram_outdir}/{self.short_project_id}-ヒストグラム-1回目の教師付者ごと-1回目の教師付時間"
+        output_file_first_worktime = f"{self.histogram_outdir}/{self.filename_prefix}ヒストグラム-1回目の教師付者ごと-1回目の教師付時間"
         logger.debug(f"{output_file_first_worktime}.html を出力します。")
 
         first_annotation_user_id_list = df["first_annotation_user_id"].dropna().unique().tolist()
@@ -150,9 +151,9 @@ class Histogram:
             logger.info("タスク一覧が0件のため出力しません。")
             return
 
-        output_file_worktime = f"{self.histogram_outdir}/{self.short_project_id}-ヒストグラム-1回目の検査者ごと-検査時間"
+        output_file_worktime = f"{self.histogram_outdir}/{self.filename_prefix}ヒストグラム-1回目の検査者ごと-検査時間"
         logger.debug(f"{output_file_worktime}.html を出力します。")
-        output_file_first_worktime = f"{self.histogram_outdir}/{self.short_project_id}-ヒストグラム-1回目の検査者ごと-1回目の検査時間"
+        output_file_first_worktime = f"{self.histogram_outdir}/{self.filename_prefix}ヒストグラム-1回目の検査者ごと-1回目の検査時間"
         logger.debug(f"{output_file_first_worktime}.html を出力します。")
 
         first_inspection_user_id_list = df["first_inspection_user_id"].dropna().unique().tolist()
@@ -201,9 +202,9 @@ class Histogram:
             logger.info("タスク一覧が0件のため出力しません。")
             return
 
-        output_file_worktime = f"{self.histogram_outdir}/{self.short_project_id}-ヒストグラム-1回目の受入者ごと-受入時間"
+        output_file_worktime = f"{self.histogram_outdir}/{self.filename_prefix}ヒストグラム-1回目の受入者ごと-受入時間"
         logger.debug(f"{output_file_worktime}.html を出力します。")
-        output_file_first_worktime = f"{self.histogram_outdir}/{self.short_project_id}-ヒストグラム-1回目の受入者ごと-1回目の受入時間"
+        output_file_first_worktime = f"{self.histogram_outdir}/{self.filename_prefix}ヒストグラム-1回目の受入者ごと-1回目の受入時間"
         logger.debug(f"{output_file_first_worktime}.html を出力します。")
 
         first_acceptance_user_id_list = df["first_acceptance_user_id"].dropna().unique().tolist()
@@ -253,7 +254,7 @@ class Histogram:
 
         renderer = hv.renderer("bokeh")
 
-        output_file = f"{self.histogram_outdir}/{self.short_project_id}-ヒストグラム-作業時間"
+        output_file = f"{self.histogram_outdir}/{self.filename_prefix}ヒストグラム-作業時間"
         logger.debug(f"{output_file}.html を出力します。")
 
         histogram_name_list = [
@@ -321,7 +322,7 @@ class Histogram:
 
         renderer = hv.renderer("bokeh")
 
-        output_file = f"{self.histogram_outdir}/{self.short_project_id}-ヒストグラム"
+        output_file = f"{self.histogram_outdir}/{self.filename_prefix}ヒストグラム"
         logger.debug(f"{output_file}.html を出力します。")
 
         histogram_name_list = [
@@ -366,7 +367,7 @@ class Histogram:
 
         renderer = hv.renderer("bokeh")
 
-        output_file = f"{self.histogram_outdir}/{self.short_project_id}-ヒストグラム-ラベルごとのアノテーション数"
+        output_file = f"{self.histogram_outdir}/{self.filename_prefix}ヒストグラム-ラベルごとのアノテーション数"
         logger.debug(f"{output_file}.html を出力します。")
 
         histograms = []
