@@ -1,13 +1,12 @@
 import logging
 from pathlib import Path
-from typing import List, Optional
+from typing import Any, List, Optional, Sequence
 
 import bokeh
 import bokeh.layouts
 import bokeh.palettes
 import pandas
 from annofabapi.models import TaskPhase
-from bokeh.core.properties import Color
 from bokeh.models import HoverTool
 from bokeh.plotting import ColumnDataSource, figure
 
@@ -19,6 +18,12 @@ logger = logging.getLogger(__name__)
 class Scatter:
     """
     散布図を出力するクラス
+
+    Args:
+        outdir: 出力先のディレクトリ
+        filename_prefix: 出力するファイルのプレフィックス
+        palette: 散布図を出力するときのカラーパレット。デフォルトは `bokeh.palettes.Category20[20]`
+
     """
 
     my_palette = bokeh.palettes.Category20[20]
@@ -37,10 +42,12 @@ class Scatter:
     # Private
     #############################################
 
-    def __init__(self, outdir: str, filename_prefix: Optional[str] = None):
+    def __init__(self, outdir: str, filename_prefix: Optional[str] = None, palette: Optional[Sequence[str]] = None):
         self.scatter_outdir = outdir
         self.filename_prefix = filename_prefix + "-" if filename_prefix is not None else ""
         Path(self.scatter_outdir).mkdir(exist_ok=True, parents=True)
+        if palette is not None:
+            self.my_palette = palette
 
     @staticmethod
     def _set_legend(fig: bokeh.plotting.Figure) -> None:
@@ -75,7 +82,7 @@ class Scatter:
         x_column_name: str,
         y_column_name: str,
         legend_label: str,
-        color: Color,
+        color: Any,
     ) -> None:
         """
         丸でプロットして、ユーザ名を表示する。
@@ -147,13 +154,16 @@ class Scatter:
         ]
 
         df["biography"] = df["biography"].fillna("")
-        for biography_index, biography in enumerate(df["biography"].unique()):
+
+        for biography_index, biography in enumerate(set(df["biography"])):
             x_column = "monitored_worktime_hour"
             y_column = "monitored_worktime/annotation_count"
             for fig, phase in zip(figure_list, phase_list):
                 filtered_df = df[
                     (df["biography"] == biography) & df[(x_column, phase)].notna() & df[(y_column, phase)].notna()
                 ]
+                if len(filtered_df) == 0:
+                    continue
                 source = ColumnDataSource(data=filtered_df)
                 self._scatter(
                     fig=fig,
@@ -215,13 +225,15 @@ class Scatter:
         ]
 
         df["biography"] = df["biography"].fillna("")
-        for biography_index, biography in enumerate(df["biography"].unique()):
+        for biography_index, biography in enumerate(set(df["biography"])):
             x_column = "prediction_actual_worktime_hour"
             y_column = "actual_worktime/annotation_count"
             for fig, phase in zip(figure_list, phase_list):
                 filtered_df = df[
                     (df["biography"] == biography) & df[(x_column, phase)].notna() & df[(y_column, phase)].notna()
                 ]
+                if len(filtered_df) == 0:
+                    continue
                 source = ColumnDataSource(data=filtered_df)
                 self._scatter(
                     fig=fig,
@@ -287,13 +299,15 @@ class Scatter:
         phase = "annotation"
 
         df["biography"] = df["biography"].fillna("")
-        for biography_index, biography in enumerate(df["biography"].unique()):
+        for biography_index, biography in enumerate(set(df["biography"])):
             for column_pair, fig in zip(column_pair_list, figure_list):
                 x_column = column_pair[0]
                 y_column = column_pair[1]
                 filtered_df = df[
                     (df["biography"] == biography) & df[(x_column, phase)].notna() & df[(y_column, phase)].notna()
                 ]
+                if len(filtered_df) == 0:
+                    continue
 
                 source = ColumnDataSource(data=filtered_df)
                 self._scatter(
